#!/usr/bin/env python3
# coding: utf-8

"""Top-level package for radicl."""

__author__ = """Micah Johnson"""
__email__ = 'info@adventuredata.com'
__version__ = '0.5.0'
